@@ -1,7 +1,4 @@
-
 #' Load the NCI60 data from GitHub
-#' 
-#' @importFrom downloader download
 #' @export
 #' @examples 
 #' 
@@ -13,8 +10,10 @@ etl_NCI60 <- function() {
   NCI60 <- data.frame()
   dir <- tempdir()
   lcl <- file.path(dir, "NCI60.rda")
-  downloader::download("https://github.com/beanumber/mdsr/blob/master/data-raw/NCI60.rda?raw=true", 
-                destfile = lcl)
+  downloader::download(
+    "https://github.com/beanumber/mdsr/blob/master/data-raw/NCI60.rda?raw=true", 
+    destfile = lcl
+  )
   load(lcl)
   return(dplyr::as.tbl(NCI60))
 }
\ No newline at end of file
